Welcome to Parslet
==================

.. toctree::
   :maxdepth: 2
   :caption: User Guide

   introduction
   install
   usage
   examples
   use_cases
   cli
   tasks
   battery_mode
   exporting

.. toctree::
   :maxdepth: 2
   :caption: Architecture

   architecture
   security
   compatibility

.. toctree::
   :maxdepth: 2
   :caption: Development

   contributing
   testing
   challenge
   benchmark_results
